@@ -9,7 +9,7 @@ from datetime import datetime
 from os.path import join
 
 from bundlewrap.exceptions import BundleError
-from bundlewrap.utils import LOG
+from bundlewrap.utils import cached_property, LOG
 from bundlewrap.utils.text import mark_for_translation as _
 from bundlewrap.utils.text import bold, wrap_question
 from bundlewrap.utils.ui import ask_interactively
@@ -18,6 +18,7 @@ BUILTIN_ITEM_ATTRIBUTES = {
     'cascade_skip': True,
     'needs': [],
     'needed_by': [],
+    'preceded_by': [],
     'triggered': False,
     'triggers': [],
     'unless': "",
@@ -86,6 +87,7 @@ class Item(object):
         self.item_data_dir = join(bundle.bundle_data_dir, self.BUNDLE_ATTRIBUTE_NAME)
         self.name = name
         self.node = bundle.node
+        self._precedes_items = []
 
         if not skip_validation:
             if not skip_name_validation:
@@ -147,6 +149,37 @@ class Item(object):
                     bundle2=self.bundle.name,
                 ))
 
+    @cached_property
+    def cached_status(self):
+        return self.get_status()
+
+    @cached_property
+    def cached_unless_result(self):
+        if self.unless and not self.cached_status.correct:
+            unless_result = self.node.run(self.unless, may_fail=True)
+            return unless_result.return_code == 0
+        else:
+            return False
+
+    def _precedes_incorrect_item(self, interactive=False):
+        """
+        Returns True if this item precedes another and the triggering
+        item is in need of fixing.
+        """
+        for item in self._precedes_items:
+            if item._precedes_incorrect_item():
+                return True
+        if self.cached_unless_result:
+            # triggering item failed unless, so there is nothing to do
+            return False
+        if self.ITEM_TYPE_NAME == 'action':
+            if self.attributes['interactive'] != interactive or \
+                    self.attributes['interactive'] is None:
+                return False
+            else:
+                return True
+        return not self.cached_status.correct
+
     def _prepare_deps(self, items):
         # merge static and user-defined deps
         self._deps = list(self.NEEDS_STATIC)
@@ -216,15 +249,12 @@ class Item(object):
             LOG.debug(_("skipping {} because it wasn't triggered").format(self.id))
             status_code = self.STATUS_SKIPPED
 
-        if status_code is None:
-            status_before = self.get_status()
-            if self.unless and not status_before.correct:
-                unless_result = self.node.run(self.unless, may_fail=True)
-                if unless_result.return_code == 0:
-                    LOG.debug(_("'unless' for {} succeeded, not fixing").format(self.id))
-                    status_code = self.STATUS_SKIPPED
+        if status_code is None and self.cached_unless_result:
+            LOG.debug(_("'unless' for {} succeeded, not fixing").format(self.id))
+            status_code = self.STATUS_SKIPPED
 
         if status_code is None:
+            status_before = self.cached_status
             if status_before.correct:
                 status_code = self.STATUS_OK
 
