@@ -8,11 +8,13 @@ from .text import mark_for_translation as _
 
 
 def _parse_file_output(file_output):
-    if file_output.startswith("cannot open `"):
+    if file_output.startswith("cannot open "):
+        # required for Mac OS X and CentOS/RHEL
         return ('nonexistent', "")
     elif file_output in ("directory", "sticky directory"):
         return ('directory', file_output)
-    elif file_output in ("block special", "character special"):
+    elif file_output.startswith("block special") or \
+            file_output.startswith("character special"):
         return ('other', file_output)
     elif file_output.startswith("symbolic link to ") or \
             file_output.startswith("broken symbolic link to "):
